OC.L10N.register(
    "mail",
    {
    "Mail" : "Məktub",
    "Auto detect failed. Please use manual mode." : "Avtomatik təyinatda səhv baş verdi. Xahiş olunur əl rejimini seçəsiniz.",
    "Creating account failed: " : "Hesabın yaradılmasında səhv:",
    "Connect" : "Qoşul",
    "Sending …" : "Göndərilir...",
    "Send" : "Göndər",
    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
    "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi"
},
"nplurals=2; plural=(n != 1);");
